@@ -36,7 +36,7 @@ import subprocess
 
 from docopt import docopt
 
-__version__ = '0.4.0'
+__version__ = '0.4.1'
 __author__ = 'Steven Loria'
 __license__ = 'MIT'
 
@@ -363,8 +363,9 @@ def resolve_path(filename):
     Return the absolute path of the file.
     """
     current = os.getcwd()
-    sentinal_dir = os.path.join(__get_home_directory(), '..')
-    while current != sentinal_dir:
+    # Stop search at home directory
+    sentinel_dir = os.path.abspath(os.path.join(__get_home_directory(), '..'))
+    while current != sentinel_dir:
         target = os.path.join(current, filename)
         if os.path.exists(target):
             return os.path.abspath(target)
@@ -414,7 +415,7 @@ def init_config(config_file=None):
 def edit_config(config_file=None, editor=None):
     filename = config_file or resolve_path(DEFAULT_CONFIG_FILE)
     print('Editing file: "{0}"'.format(filename))
-    edit_file(filename, editor=None)
+    edit_file(filename, editor=editor)
     sys.exit(0)
 
 def parse_args():
